"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var apollo_cache_1 = require("apollo-cache");
var apollo_utilities_1 = require("apollo-utilities");
var deepmerge = require("deepmerge");
var utils_1 = require("./utils");
var ApolloCacheLite = (function (_super) {
    tslib_1.__extends(ApolloCacheLite, _super);
    function ApolloCacheLite(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this) || this;
        _this.store = {};
        _this.queries = {};
        _this.watchers = [];
        _this.options = {
            getIdFromObject: utils_1.getDefaultIdFromNode
        };
        _this.options = tslib_1.__assign(tslib_1.__assign({}, _this.options), options);
        _this.reset();
        return _this;
    }
    ApolloCacheLite.prototype.diff = function (query) {
        var result = this.read(query);
        return {
            complete: !!result,
            result: result
        };
    };
    ApolloCacheLite.prototype.watch = function (watcher) {
        var _this = this;
        this.watchers.push(watcher);
        return function () {
            _this.watchers = _this.watchers.filter(function (w) { return w !== watcher; });
        };
    };
    ApolloCacheLite.prototype.write = function (options) {
        var result = options.result, query = options.query, variables = options.variables;
        var nodes = utils_1.getCacheableNodes(result, this.options.getIdFromObject);
        var hash = utils_1.getHashForQuery({ query: query, variables: variables });
        this.store = deepmerge(this.store, nodes);
        this.queries[hash] = result;
    };
    ApolloCacheLite.prototype.read = function (query) {
        var hash = utils_1.getHashForQuery(query);
        if (this.queries[hash]) {
            return this.queries[hash];
        }
    };
    ApolloCacheLite.prototype.readFragment = function (options) {
        try {
            var _a = options.id.split(':'), type = _a[0], id = _a[1];
            return this.store[type][id];
        }
        catch (e) {
            return;
        }
    };
    ApolloCacheLite.prototype.extract = function () {
        return {
            queries: tslib_1.__assign({}, this.queries),
            store: tslib_1.__assign({}, this.store)
        };
    };
    ApolloCacheLite.prototype.restore = function (serialisedState) {
        var queries = serialisedState.queries, store = serialisedState.store;
        this.queries = queries;
        this.store = store;
        try {
            window.__APOLLO_STATE__ = {
                queries: this.queries,
                store: this.store
            };
        }
        catch (e) { }
        return this;
    };
    ApolloCacheLite.prototype.reset = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.store = {};
                this.queries = {};
                this.watchers = [];
                return [2];
            });
        });
    };
    ApolloCacheLite.prototype.transformDocument = function (document) {
        return apollo_utilities_1.addTypenameToDocument(document);
    };
    ApolloCacheLite.prototype.evict = function (query) {
        throw new Error('[apollo-cache-lite] Method not implemented!');
    };
    ApolloCacheLite.prototype.removeOptimistic = function (id) {
        throw new Error('[apollo-cache-lite] Method not implemented!');
    };
    ApolloCacheLite.prototype.performTransaction = function (transaction) {
        throw new Error('[apollo-cache-lite] Method not implemented!');
    };
    ApolloCacheLite.prototype.recordOptimisticTransaction = function (transaction, id) {
        throw new Error('[apollo-cache-lite] Method not implemented!');
    };
    return ApolloCacheLite;
}(apollo_cache_1.ApolloCache));
exports.ApolloCacheLite = ApolloCacheLite;
